package session

import (
	"encoding/json"
	"github.com/smbrave/goutil"
)

type BaseResponse struct {
	Code    int    `json:"code"`
	Message string `json:"message"`
}

type CommonResponse struct {
	BaseResponse
	Data interface{} `json:"data"`
}

type RawResponse struct {
	BaseResponse
	Data json.RawMessage `json:"data"`
}

type ListResponse struct {
	BaseResponse
	Data struct {
		Total       int64       `json:"total"`
		TotalAmount string      `json:"totalAmount,omitempty"`
		Items       interface{} `json:"items"`
		Summary     interface{} `json:"summary,omitempty"`
	} `json:"data,omitempty"`
}

var (
	rspOk *BaseResponse
)

func init() {
	rspOk = new(BaseResponse)
	rspOk.Message = "OK"
	rspOk.Code = 0
}

func NewRspOk() *BaseResponse {
	return rspOk
}

func NewRawRsp(raw []byte) *RawResponse {
	rsp := &RawResponse{
		BaseResponse: BaseResponse{
			Code:    rspOk.Code,
			Message: rspOk.Message,
		},
	}
	rsp.Data = raw
	return rsp
}
func NewListRsp(total int64, items interface{}) *ListResponse {
	rsp := &ListResponse{
		BaseResponse: BaseResponse{
			Code:    rspOk.Code,
			Message: rspOk.Message,
		},
	}
	rsp.Data.Total = total
	rsp.Data.Items = items
	return rsp
}

func NewSummaryRsp(total int64, summary interface{}, items interface{}) *ListResponse {
	rsp := &ListResponse{
		BaseResponse: BaseResponse{
			Code:    rspOk.Code,
			Message: rspOk.Message,
		},
	}
	rsp.Data.Total = total
	rsp.Data.Items = items
	rsp.Data.Summary = summary
	return rsp
}

func NewListAmountRsp(total int64, totalAmount int64, items interface{}) *ListResponse {
	rsp := &ListResponse{
		BaseResponse: BaseResponse{
			Code:    rspOk.Code,
			Message: rspOk.Message,
		},
	}
	rsp.Data.Total = total
	rsp.Data.TotalAmount = goutil.FormatMoney(totalAmount)
	rsp.Data.Items = items
	return rsp
}

func NewRsp(data interface{}) *CommonResponse {
	return &CommonResponse{
		BaseResponse: BaseResponse{
			Code:    rspOk.Code,
			Message: rspOk.Message,
		},
		Data: data,
	}
}
